@@ -22,10 +22,12 @@ int main(int argc, const char *argv[]) {
   CFStringAppend(path, prefix);
   CFStringAppendCString(path, "/", encoding);
   CFStringAppend(path, resources);
+  CFStringAppendCString(path, "/usr/local/", encoding);
 
   setenv("FRICAS_PREFIX", CFStringGetCStringPtr(path, encoding), 1);
 
   system("open -a Terminal.app"
-         " \"${FRICAS_PREFIX}/usr/local/bin/fricas\"");
+         " -n --env FRICAS_PREFIX=\"${FRICAS_PREFIX}\""
+         " \"${FRICAS_PREFIX}/bin/fricas\"");
   return 0;
 }
